@@ -14,18 +14,18 @@ cd /tmp/ || die "Can't chdir to /tmp/ ."
 
 if [ ! -r kernel-3.19.8-100.fc20.src.rpm ]
 then
-    wget http://ftp.riken.jp/Linux/fedora/updates/20/SRPMS/kernel-3.19.8-100.fc20.src.rpm || die "Can't download source package."
+    wget https://archives.fedoraproject.org/pub/archive/fedora/linux/updates/20/SRPMS/kernel-3.19.8-100.fc20.src.rpm || die "Can't download source package."
 fi
 LANG=C rpm --checksig kernel-3.19.8-100.fc20.src.rpm | grep -F ': rsa sha1 (md5) pgp md5 OK' || die "Can't verify signature."
 rpm -ivh kernel-3.19.8-100.fc20.src.rpm || die "Can't install source package."
 
-cd /root/rpmbuild/SOURCES/ || die "Can't chdir to /root/rpmbuild/SOURCES/ ."
+cd ~/rpmbuild/SOURCES/ || die "Can't chdir to ~/rpmbuild/SOURCES/ ."
 if [ ! -r ccs-patch-1.8.5-20160808.tar.gz ]
 then
     wget -O ccs-patch-1.8.5-20160808.tar.gz 'http://osdn.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.5-20160808.tar.gz' || die "Can't download patch."
 fi
 
-cd /root/rpmbuild/SPECS/ || die "Can't chdir to /root/rpmbuild/SPECS/ ."
+cd ~/rpmbuild/SPECS/ || die "Can't chdir to ~/rpmbuild/SPECS/ ."
 cp -p kernel.spec ccs-kernel.spec || die "Can't copy spec file."
 patch << "EOF" || die "Can't patch spec file."
 --- ccs-kernel.spec
@@ -99,12 +99,12 @@ EOF
 echo ""
 echo ""
 echo ""
-echo "Edit /root/rpmbuild/SPECS/ccs-kernel.spec if needed, and run"
-echo "rpmbuild -bb /root/rpmbuild/SPECS/ccs-kernel.spec"
+echo "Edit ~/rpmbuild/SPECS/ccs-kernel.spec if needed, and run"
+echo "rpmbuild -bb ~/rpmbuild/SPECS/ccs-kernel.spec"
 echo "to build kernel rpm packages."
 echo ""
 ARCH=`uname -m`
-echo "I'll start 'rpmbuild -bb --target $ARCH --without debug --without debuginfo /root/rpmbuild/SPECS/ccs-kernel.spec' in 30 seconds. Press Ctrl-C to stop."
+echo "I'll start 'rpmbuild -bb --target $ARCH --without debug --without debuginfo ~/rpmbuild/SPECS/ccs-kernel.spec' in 30 seconds. Press Ctrl-C to stop."
 sleep 30
-exec rpmbuild -bb --target $ARCH --without debug --without debuginfo /root/rpmbuild/SPECS/ccs-kernel.spec
+exec rpmbuild -bb --target $ARCH --without debug --without debuginfo ~/rpmbuild/SPECS/ccs-kernel.spec
 exit 0
