@@ -17,14 +17,14 @@ fi
 LANG=C rpm --checksig kernel-3.4.110-4vl6.src.rpm | grep -F ': (sha1) dsa sha1 md5 gpg OK' || die "Can't verify signature."
 rpm -ivh kernel-3.4.110-4vl6.src.rpm || die "Can't install source package."
 
-cd /root/rpm/SOURCES/ || die "Can't chdir to /root/rpm/SOURCES/ ."
+cd ~/rpm/SOURCES/ || die "Can't chdir to ~/rpm/SOURCES/ ."
 if [ ! -r ccs-patch-1.8.5-20160808.tar.gz ]
 then
     wget -O ccs-patch-1.8.5-20160808.tar.gz 'http://osdn.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.5-20160808.tar.gz' || die "Can't download patch."
 fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
-cp -p /root/rpm/SPECS/kernel34-vl.spec . || die "Can't copy spec file."
+cp -p ~/rpm/SPECS/kernel34-vl.spec . || die "Can't copy spec file."
 patch << "EOF" || die "Can't patch spec file."
 --- kernel34-vl.spec
 +++ kernel34-vl.spec
